@@ -1,9 +1,9 @@
+#
 # fields  is a package for analysis of spatial data written for
-# the R software environment .
-# Copyright (C) 2017
-# University Corporation for Atmospheric Research (UCAR)
-# Contact: Douglas Nychka, nychka@ucar.edu,
-# National Center for Atmospheric Research, PO Box 3000, Boulder, CO 80307-3000
+# the R software environment.
+# Copyright (C) 2024 Colorado School of Mines
+# 1500 Illinois St., Golden, CO 80401
+# Contact: Douglas Nychka,  douglasnychka@gmail.com,
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -17,7 +17,8 @@
 # You should have received a copy of the GNU General Public License
 # along with the R software environment if not, write to the Free Software
 # Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
-# or see http://www.r-project.org/Licenses/GPL-2    
+# or see http://www.r-project.org/Licenses/GPL-2
+##END HEADER
 "parse.grid.list" <- function(grid.list, order.variables = "xy") {
     #
     # utility to find the x and y sequences in grid.list
@@ -25,13 +26,21 @@
     #
     M <- length(grid.list)
     gcounts <- unlist(lapply(grid.list, FUN = length))
-    xy <- (1:M)[gcounts > 1]
+    
+    xy <- (1:M)[(gcounts > 1)]
+    
+    if( length(xy) ==1){
+       xy<- sort( c(xy,  which(gcounts == 1 ) ) )
+    }
+    
+    
     if (length(xy) > 2) {
         stop("only two components of the grid list\ncan have more than one element")
     }
+    
     #
-    # swap the roles of x and y
-    if (order.variables == "yx") {
+    # swap the roles of x and y for 2D grid
+    if (order.variables == "yx" & (M!=1) ) {
         xy <- xy[2:1]
     }
     #
